icc.de.mat: Computation of Double-Entry Intraclass Correlations for correlation
matrices
Description
This function computes pairwise double-entry intraclass correlations among
all entries of a data frame. Correlations between the compared variables as well
as correlations of the constructs with themselves are thereby excluded from the
calculation (i.e., correlations between X and Y, correlation between X and X,
and correlation between Y and Y).
Usage
icc.de.mat(data, use = "pairwise", digit)
Value
A matrix of double-entry intraclass correlations among the entered
variables.
Arguments
data
A data frame with participants in rows and variables in columns.
use
Optional character string specifying how to deal with missing values.
The input will be forwarded to the base cor function and can be one of
the following strings, including abbreviation: "everything", "all.obs",
"complete.obs", "na.or.complete", or "pairwise.complete.obs". The default is
use = "pairwise".
Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an Index of
Profile Similarity: Meaning, Limitations, and Alternatives. Journal of
Personality Assessment, 92(1), 1--15.
https://doi.org/10.1080/00223890903379134
McCrae, R. R. (2008). A Note on Some Measures of Profile Agreement. Journal of
Personality Assessment, 90(2), 105--109.
https://doi.org/10.1080/00223890701845104