iccde: Computation of the Double-Entry Intraclass Correlation...

iccdeR Documentation

Computation of the Double-Entry Intraclass Correlation between two profiles

Description

The function computes the double-entry intraclass correlation, which is an index of profile similarity (Furr, 2010; McCrae, 2008). The double-entry intraclass correlation is a more precise index of the agreement of two empirically observed profiles than the often-used intraclass correlation (McCrae, 2008). The function transforms profiles comprising correlations according to the Fisher z-transformation before the double-entry intraclass correlation is calculated. If the profiles comprise scores such as sum scores from various personality scales, it is recommended to standardize each individual score prior to computation of the double-entry intraclass correlation (McCrae, 2008). See Furr (2010) <doi:10.1080/00223890903379134> or McCrae (2008) <doi:10.1080/00223890701845104> for details.

Usage

icc.de(prof1,
       prof2,
       input = c("cor", "score"),
       use = "pairwise",
       digits = 2,
       plot = TRUE,
       legend = TRUE,
       pos.legend = "topleft",
       main = NA,
       name_prof1 = "prof1",
       name_prof2 = "prof2")

Arguments

prof1

Vector of components of the nomological network of the first variable (input = "cor") or vector of components of the first profile (input = "score").

prof2

Vector of components of the nomological network of the second variable (input = "cor") or vector of components of the second profile (input = "score").

input

Do the profiles contain correlations (e.g., from nomological network; input = "cor") or scores from different scales (e.g., sum scores from diverse personality tests; input = "score")? The default is input = "cor".

use

Optional character string specifying how to deal with missing values. The input will be forwarded to the base cor function and can be one of the following strings, including abbreviation: "everything", "all.obs", "complete.obs", "na.or.complete", or "pairwise.complete.obs". The default is use = "pairwise".

digits

Number of digits in the output. The default is digits = 2.

plot

Optional. Should the trajectories be visualized?

legend

Optional. Should a legend be added to the plot?

pos.legend

Optional. If legend = TRUE, the position of the legend can be specified. The edible default is pos.legend = "topleft". Alternative positions are "bottomright", "bottom", "bottomleft", "left", "top", "topright", "right", and "center".

main

Optional. Header/title of the optional plot.

name_prof1

Optional. Alternative name to be displayed in the output for prof1.

name_prof2

Optional. Alternative name to be displayed in the output for prof2.

Value

iccde

Double-Entry Intraclass Correlation for two given profiles

Mean_prof1, Mean_prof2

Means of the coefficients entered as prof1 and prof2, respectively.

SD_prof1, SD_prof2

Standard deviation of the coefficients entered as prof1 and prof2, respectively.

Author(s)

Christian Blötner, Michael Paul Grosz c.bloetner@gmail.com

References

Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an Index of Profile Similarity: Meaning, Limitations, and Alternatives. Journal of Personality Assessment, 92(1), 1–15. https://doi.org/10.1080/00223890903379134

McCrae, R. R. (2008). A Note on Some Measures of Profile Agreement. Journal of Personality Assessment, 90(2), 105–109. https://doi.org/10.1080/00223890701845104

Examples

icc.de(prof1 = c(.59, .48, .23),
       prof2 = c(.52, .76, .22),
       input = "cor")

icc.de(prof1 = c(-1, -0.85, 2),
       prof2 = c(-0.93, 1, 1.26),
       input = "score",
       digits = 4)

iccde documentation built on June 13, 2026, 1:06 a.m.

Related to iccde in iccde...