| icc.de.boot | R Documentation |
For different applications, confidence intervals for the double- entry intraclass correlation can be useful. Bootstrap confidence intervals are computed by means of repeated resampling from the original data at hand.
icc.de.boot(data,
n.sim = 1000,
alpha = .05,
use = "pairwise",
digit = 3)
data |
A data frame with participants in rows and variables in columns. Users should restrict the data set to the variables of concrete interest because the all available information in the data frame will be used to compute bootstrapped confidence intervals. Thus, it is advisable to create a new data frame that entails only the variables on which the matrix of ICCDEs should be based. |
n.sim |
The number of iterations to be carried out. Default is 1,000. |
alpha |
Type I error. Default is .05. |
use |
Optional character string specifying how to deal with missing values.
The input will be forwarded to the base |
digit |
Number of digits in the output. Default is 3. |
The output provides a list with the following elements.
M |
A matrix of the bootstrapped point estimates of the bootstrapped double-entry intraclass correlations. |
LL |
A matrix providing the lower limits of the bootstrap confidence intervals, given the desired alpha level. |
UL |
A matrix providing the upper limits of the bootstrap confidence intervals, given the selected alpha level. |
Mean |
A vector of the mean correlation per row of the raw correlation matrix (i.e., not bootstrapped), excluding the diagonal element. |
SD |
A vector of the standard deviations of the correlations per row of the raw correlation matrix (i.e., not bootstrapped), excluding the diagonal element. |
Christian Blötner, Michael Paul Grosz c.bloetner@gmail.com
Furr, R. M. (2010). The Double-Entry Intraclass Correlation as an index of profile similarity: Meaning, limitations, and alternatives. Journal of Personality Assessment, 92(1), 1–15. <https://doi.org/10.1080/00223890903379134>
McCrae, R. R. (2008). A note on some measures of profile agreement. Journal of Personality Assessment, 90(2), 105–109. <https://doi.org/10.1080/00223890701845104>
df <- data.frame(a = rnorm(100), b = rnorm(100), c = rnorm(100),
x = rnorm(100), y = rnorm(100), z = rnorm(100))
icc.de.boot(data = df,
n.sim = 10, # just for illustration. Use higher n.sim in real data
alpha = .01,
digit = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.